@@ -169,7 +169,7 @@ class StickProtocol():
             group = self.Group.objects.get(id=stickId[:36])
             if group in user.invited_groups.all():
                 authorized = True
-        elif stickId.startswith(user.parties.filter(individual=False).id) or stickId.startswith(user.parties.filter(individual=True).id):  # A user is authorized to fetch SenderKeys of their own profile (user.party.id)
+        elif stickId.startswith(user.parties.get(individual=False).id) or stickId.startswith(user.parties.get(individual=True).id):  # A user is authorized to fetch SenderKeys of their own profile (user.party.id)
             authorized = True
         else:
             groupId = stickId[:36]
